Coverage report

File | function | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/cycloplanning/__init__.py | get_html | 2 | 2 | 0 | 0%
src/cycloplanning/__init__.py | parse_html | 11 | 1 | 0 | 91%
src/cycloplanning/__init__.py | parse_events | 12 | 0 | 0 | 100%
src/cycloplanning/__init__.py | create_ics | 5 | 0 | 0 | 100%
src/cycloplanning/__init__.py | write_ics | 2 | 2 | 0 | 0%
src/cycloplanning/__init__.py | (no function) | 19 | 0 | 0 | 100%
src/cycloplanning/cli.py | main | 1 | 1 | 0 | 0%
src/cycloplanning/cli.py | (no function) | 9 | 9 | 0 | 0%
Total |  | 61 | 15 | 0 | 75%

No items found using the specified filter.